@@ -395,7 +395,7 @@ def test_write_to_bytes():
 
     # writing to bytes with imageIO
     with io.BytesIO() as output:
-        iio.v3.imwrite(output, image, plugin="pillow", format_hint=".png")
+        iio.v3.imwrite(output, image, plugin="pillow", extension=".png")
         iio_contents = output.getvalue()
 
     assert iio_contents == contents
@@ -411,7 +411,7 @@ def test_write_to_bytes_rgba():
 
     # writing to bytes with imageIO
     with io.BytesIO() as output:
-        iio.v3.imwrite(output, image, plugin="pillow", format_hint=".png", mode="RGBA")
+        iio.v3.imwrite(output, image, plugin="pillow", extension=".png", mode="RGBA")
         iio_contents = output.getvalue()
 
     assert iio_contents == contents
@@ -426,7 +426,7 @@ def test_write_to_bytes_imwrite():
         contents = output.getvalue()
 
     # write with ImageIO
-    bytes_string = iio.v3.imwrite("<bytes>", image, plugin="pillow", format_hint=".png")
+    bytes_string = iio.v3.imwrite("<bytes>", image, plugin="pillow", extension=".png")
 
     assert contents == bytes_string
 
@@ -440,9 +440,7 @@ def test_write_to_bytes_jpg():
         contents = output.getvalue()
 
     # write with ImageIO
-    bytes_string = iio.v3.imwrite(
-        "<bytes>", image, plugin="pillow", format_hint=".jpeg"
-    )
+    bytes_string = iio.v3.imwrite("<bytes>", image, plugin="pillow", extension=".jpeg")
 
     assert contents == bytes_string
 
@@ -453,7 +451,7 @@ def test_write_jpg_to_bytes_io():
 
     image = np.zeros((200, 200), dtype=np.uint8)
     bytes_io = io.BytesIO()
-    iio.v3.imwrite(bytes_io, image, plugin="pillow", format_hint=".jpeg", mode="L")
+    iio.v3.imwrite(bytes_io, image, plugin="pillow", extension=".jpeg", mode="L")
     bytes_io.seek(0)
 
     image_from_file = iio.v3.imread(bytes_io, plugin="pillow")
@@ -578,7 +576,7 @@ def test_apng_metadata(tmp_path, test_images):
 
 def test_write_format_warning():
     frames = iio.v3.imread("imageio:chelsea.png")
-    bytes_image = iio.v3.imwrite("<bytes>", frames, format_hint=".png", plugin="pillow")
+    bytes_image = iio.v3.imwrite("<bytes>", frames, extension=".png", plugin="pillow")
 
     with pytest.warns(UserWarning):
         old_bytes = iio.v3.imwrite("<bytes>", frames, plugin="pillow", format="PNG")
